# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApiListEnvironmentVariablesResponse
from ..models import ResponseError

from ..operations.environment_variables import EnvironmentVariableList


@same_doc_as(EnvironmentVariableList)
def environment_variable_list(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """List environment variables (EnvironmentVariableList)

    Required Permission: ADMIN:MATCHMAKING:CONFIGURATION:ENVIRONMENTVARIABLE [READ]

    Required Scope: social

    List environment variables.

    Required Permission(s):
        - ADMIN:MATCHMAKING:CONFIGURATION:ENVIRONMENTVARIABLE [READ]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/environment-variables

        method: GET

        tags: ["Environment-Variables", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - ApiListEnvironmentVariablesResponse (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = EnvironmentVariableList.create()
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(EnvironmentVariableList)
async def environment_variable_list_async(
    x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """List environment variables (EnvironmentVariableList)

    Required Permission: ADMIN:MATCHMAKING:CONFIGURATION:ENVIRONMENTVARIABLE [READ]

    Required Scope: social

    List environment variables.

    Required Permission(s):
        - ADMIN:MATCHMAKING:CONFIGURATION:ENVIRONMENTVARIABLE [READ]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/environment-variables

        method: GET

        tags: ["Environment-Variables", "admin"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

    Responses:
        200: OK - ApiListEnvironmentVariablesResponse (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)
    """
    request = EnvironmentVariableList.create()
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
